# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AssistantFile(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    The unique identifier of the file.
    """

    object: typing.Optional[str] = None
    created_at: int = pydantic.Field()
    """
    The unix timestamp of when the file was created.
    """

    assistant_id: str = pydantic.Field()
    """
    The unique identifier of the assistant.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    LettaStreamingResponse,
    LettaStreamingResponse_AssistantMessage,
    LettaStreamingResponse_ReasoningMessage,
    LettaStreamingResponse_SystemMessage,
    LettaStreamingResponse_ToolCallMessage,
    LettaStreamingResponse_ToolReturnMessage,
    LettaStreamingResponse_UsageStatistics,
    LettaStreamingResponse_UserMessage,
    MessagesListResponse,
    MessagesListResponseItem,
    MessagesListResponseItem_AssistantMessage,
    MessagesListResponseItem_ReasoningMessage,
    MessagesListResponseItem_SystemMessage,
    MessagesListResponseItem_ToolCallMessage,
    MessagesListResponseItem_ToolReturnMessage,
    MessagesListResponseItem_UserMessage,
)

__all__ = [
    "LettaStreamingResponse",
    "LettaStreamingResponse_AssistantMessage",
    "LettaStreamingResponse_ReasoningMessage",
    "LettaStreamingResponse_SystemMessage",
    "LettaStreamingResponse_ToolCallMessage",
    "LettaStreamingResponse_ToolReturnMessage",
    "LettaStreamingResponse_UsageStatistics",
    "LettaStreamingResponse_UserMessage",
    "MessagesListResponse",
    "MessagesListResponseItem",
    "MessagesListResponseItem_AssistantMessage",
    "MessagesListResponseItem_ReasoningMessage",
    "MessagesListResponseItem_SystemMessage",
    "MessagesListResponseItem_ToolCallMessage",
    "MessagesListResponseItem_ToolReturnMessage",
    "MessagesListResponseItem_UserMessage",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import SyncClientWrapper
import typing
from ...core.request_options import RequestOptions
from ...types.context_window_overview import ContextWindowOverview
from ...core.jsonable_encoder import jsonable_encoder
from ...core.unchecked_base_model import construct_type
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper


class ContextClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(self, agent_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ContextWindowOverview:
        """
        Retrieve the context window of a specific agent.

        Parameters
        ----------
        agent_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContextWindowOverview
            Successful Response

        Examples
        --------
        from letta_client import Letta

        client = Letta(
            token="YOUR_TOKEN",
        )
        client.agents.context.get(
            agent_id="agent_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/agents/{jsonable_encoder(agent_id)}/context",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ContextWindowOverview,
                    construct_type(
                        type_=ContextWindowOverview,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncContextClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self, agent_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ContextWindowOverview:
        """
        Retrieve the context window of a specific agent.

        Parameters
        ----------
        agent_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ContextWindowOverview
            Successful Response

        Examples
        --------
        import asyncio

        from letta_client import AsyncLetta

        client = AsyncLetta(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.agents.context.get(
                agent_id="agent_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/agents/{jsonable_encoder(agent_id)}/context",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ContextWindowOverview,
                    construct_type(
                        type_=ContextWindowOverview,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from .child_tool_rule import ChildToolRule
from .init_tool_rule import InitToolRule
from .terminal_tool_rule import TerminalToolRule
from .conditional_tool_rule import ConditionalToolRule

AgentStateToolRulesItem = typing.Union[ChildToolRule, InitToolRule, TerminalToolRule, ConditionalToolRule]



# This file was auto-generated by Fern from our API Definition.

from .get_run_messages_response_item import (
    GetRunMessagesResponseItem,
    GetRunMessagesResponseItem_AssistantMessage,
    GetRunMessagesResponseItem_ReasoningMessage,
    GetRunMessagesResponseItem_SystemMessage,
    GetRunMessagesResponseItem_ToolCallMessage,
    GetRunMessagesResponseItem_ToolReturnMessage,
    GetRunMessagesResponseItem_UserMessage,
)

__all__ = [
    "GetRunMessagesResponseItem",
    "GetRunMessagesResponseItem_AssistantMessage",
    "GetRunMessagesResponseItem_ReasoningMessage",
    "GetRunMessagesResponseItem_SystemMessage",
    "GetRunMessagesResponseItem_ToolCallMessage",
    "GetRunMessagesResponseItem_ToolReturnMessage",
    "GetRunMessagesResponseItem_UserMessage",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .tool_rule_type import ToolRuleType
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ChildToolRule(UncheckedBaseModel):
    """
    A ToolRule represents a tool that can be invoked by the agent.
    """

    tool_name: str = pydantic.Field()
    """
    The name of the tool. Must exist in the database for the user's organization.
    """

    type: typing.Optional[ToolRuleType] = None
    children: typing.List[str] = pydantic.Field()
    """
    The children tools that can be invoked.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
